@@ -9,7 +9,7 @@ from tqdm.auto import tqdm
 
 from pyridy.osm.utils import QueryResult, OSMLevelCrossing, OSMRailwaySwitch, OSMRailwaySignal, OSMRailwayLine, \
     OSMRailwayElement
-from pyridy.utils.tools import internet, requires_internet
+from pyridy.utils.tools import internet
 
 logger = logging.getLogger(__name__)
 
@@ -45,7 +45,7 @@ class OSMRegion:
         if not (-180 <= lon_sw <= 180) or not (-180 <= lon_ne <= 180):
             raise ValueError("Lon. value outside valid range")
 
-        self.overpass_api = overpy.Overpass()
+        self.overpass_api = overpy.Overpass(url="https://overpass.kumi.systems/api/interpreter")
 
         self.lon_sw = lon_sw
         self.lat_sw = lat_sw
@@ -106,6 +106,7 @@ class OSMRegion:
         if internet():
             for railway_type in tqdm(railway_types):
                 # Create Overpass queries and try downloading them
+                logger.info("Querying data for railway type: %s" % railway_type)
                 trk_query, rou_query = self._create_query(railway_type=railway_type)
                 trk_result = QueryResult(self.query_overpass(trk_query), railway_type)
                 rou_result = QueryResult(self.query_overpass(rou_query), railway_type)
@@ -140,7 +141,7 @@ class OSMRegion:
             try:
                 logger.info("Trying to query OSM data, %d/%d tries" % (a, attempts))
                 result = self.overpass_api.query(query)
-                logger.info("Successfully gathers OSM Data")
+                logger.info("Successfully queried OSM Data")
                 break
             except overpy.exception.OverpassTooManyRequests as e:
                 logger.warning("OverpassTooManyRequest, retrying".format(e))
@@ -172,7 +173,7 @@ class OSMRegion:
 
         return ways
 
-    def get_switches(self) -> list[OSMRailwayElement]:
+    def get_switches(self) -> List[OSMRailwayElement]:
         return [el for el in self.railway_elements if type(el) == OSMRailwaySwitch]
 
     @property
