@@ -11,7 +11,9 @@ class Device:
                  manufacturer: Union[str, Series] = None,
                  device: Union[str, Series] = None,
                  product: Union[str, Series] = None,
-                 model: Union[str, Series] = None):
+                 model: Union[str, Series] = None,
+                 gnss_hardware_model_name: Union[str, Series] = None,
+                 gnss_year_of_hardware: Union[int, Series] = None):
 
         if type(api_level) == Series:
             self.api_level = api_level[0] if len(api_level) > 0 else None
@@ -48,6 +50,19 @@ class Device:
         else:
             self.model = model
 
+        if type(gnss_hardware_model_name) == Series:
+            self.gnss_hardware_model_name = gnss_hardware_model_name[0] if len(gnss_hardware_model_name) > 0 else None
+        else:
+            self.gnss_hardware_model_name = gnss_hardware_model_name
+
+        if type(gnss_year_of_hardware) == Series:
+            self.gnss_year_of_hardware = gnss_year_of_hardware[0] if len(gnss_year_of_hardware) > 0 else None
+        else:
+            self.gnss_year_of_hardware = gnss_year_of_hardware
+
     def __repr__(self):
-        return "Brand: %s, Model: %s, Product: %s, Device: %s, Manufacturer: %s, Base OS: %s, API Level: %d " \
-               % (self.brand, self.model, self.product, self.device, self.manufacturer, self.base_os, self.api_level)
+        return "Brand: %s, Model: %s, Product: %s, Device: %s, Manufacturer: %s, Base OS: %s, API Level: %d, " \
+               "GNSS Hardware Model Name: %s, GNSS Year of Hardware" \
+               % (self.brand, self.model, self.product, self.device, self.manufacturer, self.base_os,
+                  self.api_level if self.api_level else -1, self.gnss_hardware_model_name,
+                  self.gnss_year_of_hardware if self.gnss_year_of_hardware else -1)
